@@ -100,15 +100,19 @@ function completeAjaxUpload(response,upload_id,field_type) {
 
   try {
     r = response.evalJSON(true);
-  } catch(e) { r = {success:     false, 
-                    upload_name: 'Uploaded file',
+  } catch(e) { 
+               r = {success:     false, 
+                    uploadName: 'Uploaded file',
                     error_msg:   'The server returned an error during upload'}}
 
     if (r.success) {
 
         var fields = field_type == 'upload' ? new Array(track_listing_id,userdata_table_id)
+                    :field_type == 'edit'   ? new Array(track_listing_id,userdata_table_id,userimport_table_id)
                                             : new Array(track_listing_id,userimport_table_id);
-	Controller.add_tracks(r.tracks,
+
+	if (r.tracks != null && r.tracks.length > 0) {
+  	  Controller.add_tracks(r.tracks,
 			      function() { 
 				  Controller.update_sections(
                                       fields,
@@ -121,6 +125,11 @@ function completeAjaxUpload(response,upload_id,field_type) {
                                         }
 				     )}
 				);
+	} else {
+            var updater = Ajax_Status_Updater.get(upload_id);
+            if (updater != null) updater.stop();
+            $(upload_id).remove();
+        }
     } else {
         if (Ajax_Status_Updater.get(upload_id) !=null)
              Ajax_Status_Updater.get(upload_id).stop();
@@ -196,56 +205,47 @@ function addAnUploadField(after_element,action,upload_prompt,remove_prompt,field
     script         +=                                      'completeAjaxUpload(response,\''+upload_tag+'\',\''+field_type+'\')';
     script         +=                         '}})';
 
-    var div         = new Element('div',{id:upload_tag});
-    var form        = new Element('form',{name: 'ajax_upload',
-                                            id: upload_tag + '_form',
-                                      onSubmit: script,
-				        action: action,
-                                       enctype: 'multipart/form-data',
-                                        method: 'post'
-				      });
-    var paragraph   = new Element('p');
-    form.update(paragraph);
-    paragraph.insert(new Element('a',
-    			     {href:  help_link,
-			      target:'_new'
-			     }).update('<i>[Help with the file format]</i>'));
-    paragraph.insert('<br><b>'+upload_prompt+' </b><br>');
+    var html = '<div id=UPLOAD_TAG>'
+                + '<form name=ajax_upload'
+                +        ' id="UPLOAD_TAG_form"'
+                +        ' onSubmit="SCRIPT"'
+                +        '   action="ACTION"'
+                +        '  enctype="multipart/form-data"'
+                +        '  method="POST">'
+                +    '<p>'
+                +    '<a href="HELP_LINK" target="_blank"><i>[Help with the file format]</i></a>'
+                + '<br /><b>UPLOAD_PROMPT</b><br />';
 
-    if (field_type=='upload') {
-       paragraph.insert(new Element('input',{type:'hidden', 
-                                             name:'action', 
-                                            value:'upload_file'}));
-       paragraph.insert(new Element('input',   {name:'file', id:'upload_field', type:'file'}));
-    }
+   if (field_type=='upload') {
+       html += '<input type="hidden" name="action" value="upload_file"  />'
+              +'<input type="file"   name="file"      id="upload_field" />';
+   }
+   else if (field_type=='edit') {
+       html += '<input type="hidden" name="action" value="upload_file"  />'
+             + '<input type="hidden" name="name"   value="UPLOAD_TAG"   />'
+             + '<textarea name="data" id="edit_field" rows="20" cols="100" wrap="off"></textarea>'
+             + '<br />';
+   }
+   else {
+       html += '<input type="hidden" name="action" value="import_track" />'
+             + '<input type="text"   name="url" id="import_field" size="50" />';
+   }
 
-    else if (field_type=='edit') {
-       paragraph.insert(new Element('input',{type:'hidden', 
-                                             name:'action', 
-                                            value:'upload_file'}));
-       paragraph.insert(new Element('input',{type:'hidden', 
-                                             name:'name', 
-                                            value:upload_tag}));
-       paragraph.insert(new Element('textarea',{name:'data', id:'edit_field',
-       			    		        rows:20, cols:120, wrap:'off'})); 
-    }
+   html += '<input type="submit" name="submit"    value="Upload" />'
+         + '<input type="hidden"  name="upload_id" value="UPLOAD_TAG" />'
+         + '&nbsp;<a href="javascript:void(0)" onClick="Element.extend(this);this.up(\'div\').remove()">'
+         + 'REMOVE_PROMPT</a>';
 
-    else {
-       paragraph.insert(new Element('input',{type:'hidden', 
-                                             name:'action', 
-                                            value:'import_track'}));
-       paragraph.insert(new Element('input',   {name:'url',  id:'import_field',type:'text',
-                                                size:50}));
-    }
+   html  += '</p></form><div id="UPLOAD_TAG_status"></div></div>';
 
-    paragraph.insert(new Element('input',{type:'submit', name:'submit', value:'Upload'}));
-    paragraph.insert(new Element('input',{type:'hidden', name:'upload_id',value:upload_tag}));
-    paragraph.insert(new Element('a',{   href: 'javascript:void(0)',
-                                      onClick: 'this.up("div").remove()'
-                                 }).update(' '+remove_prompt));
-    div.insert(new Element('div',{id:upload_tag+'_status'}));
-    div.insert(form);
+   // do string subsitutions
+   html = html.gsub(/SCRIPT/,script);
+   html = html.gsub(/ACTION/,action);
+   html = html.gsub(/UPLOAD_TAG/,upload_tag);
+   html = html.gsub(/UPLOAD_PROMPT/,upload_prompt);
+   html = html.gsub(/REMOVE_PROMPT/,remove_prompt);
+   html = html.gsub(/HELP_LINK/,help_link);
 
-    var el = $(after_element);
-    el.insert({before:div});
+   var el = $(after_element);
+   el.insert({before:html});
 }
