@@ -342,7 +342,15 @@ Alias        "/gbrowse2"    "$dir"
 ScriptAlias  "/gb2"      "$cgibin"
 
 <Directory "$dir">
+  AllowOverride Options
   Options -Indexes -MultiViews +FollowSymLinks
+  Order allow,deny
+  Allow from all
+</Directory>
+
+<Directory "$tmp/images/">
+  Order allow,deny
+  Allow from all
 </Directory>
 
 <Directory "$cgibin">
