@@ -1,5 +1,5 @@
 package Bio::Graphics::Browser2::DataLoader;
-# $Id: DataLoader.pm 22606 2010-01-25 00:00:13Z lstein $
+# $Id: DataLoader.pm 22837 2010-03-19 05:45:33Z lstein $
 
 use strict;
 use IO::File;
@@ -212,7 +212,7 @@ sub backend {
 sub guess_backend {
     my $self = shift;
     my %db_drivers = map {$_=>1} DBI->available_drivers(1);
-    return 'DBI::SQLite' if $db_drivers{SQLite};
+    return 'DBI::SQLite' if $db_drivers{SQLite} && eval "require Bio::DB::SeqFeature::Store::DBI::SQLite";
     return 'berkeleydb'  if eval "require Bio::DB::SeqFeature::Store::berkeleydb; 1";
     return 'DBI::mysql'  if $db_drivers{mysql};
     return 'memory';
