@@ -7,7 +7,7 @@ package Bio::Graphics::Browser2::GFFPrinter;
 #
 ###################################################################
 
-# $Id: GFFPrinter.pm 22706 2010-02-17 09:53:20Z sheldon_mckay $
+# $Id: GFFPrinter.pm 22994 2010-04-05 03:52:31Z lstein $
 
 # Dirt simple GFF3 dumper, suitable for a lightweight replacement to DAS.
 # Call this way:
@@ -409,14 +409,14 @@ sub get_scan {
 	next if        $config->code_setting($l=>'global feature');
 	my $key      = $config->code_setting($l => 'key');
 	my $citation = $config->code_setting($l => 'citation');
-	my (undef,@subtracks) = shellwords($config->code_setting($l => 'select'));
+	my $subtracks = $config->subtrack_scan_list($l);
 	$result .=  <<END;
 [$l]
 key      = $key
 END
     ;
-    $result .=  "select   = @subtracks\n" if @subtracks;
-    $result .=  "citation = $citation\n"  if $citation;
+    $result .=  "select   = @$subtracks\n" if $subtracks;
+    $result .=  "citation = $citation\n"   if $citation;
     $result .=  "\n";
     }
 return $result;
