@@ -243,10 +243,12 @@ sub make_requests {
     my @cache_extra = @{ $args->{cache_extra} || [] };
     my %d;
     foreach my $label ( @{ $labels || [] } ) {
+
+	$self->set_subtrack_defaults($label);
+
         my @track_args = $self->create_track_args( $label, $args );
 	my (@filter_args,@featurefile_args,@segment_args);
 
-
 	my $filter     = $settings->{features}{$label}{filter};
 	@filter_args   = %{$filter->{values}} if $filter->{values};
 	my $ff_error;
@@ -1327,36 +1329,31 @@ sub select_features_menu {
     my $source = $self->source;
     my $settings=$self->settings;
 
-    my ($method,@values) = shellwords $source->setting($label=>'select');
-    foreach    (@values) {s/#.+$//}  # get rid of comments
-
-    return unless @values;
-
     my $buttons = $self->source->globals->button_url;
     my $escaped_label = CGI::escape($label);
 
+    my ($method,$values,$labels)   = $source->subtrack_select_list($label) or return;
     my $filter = $settings->{features}{$label}{filter};
 
-    $filter->{values} ||= {map {$_=>1} @values};
-    $filter->{method} ||= $method;
-
-
     my @showing = grep {
  	$filter->{values}{$_}
-    } @values;
+    } @$values;
 
     my @hidden = grep {
 	!$filter->{values}{$_}
-    } @values;
+    } @$values;
 
     my $showing = @showing;
     my $total   = @showing+@hidden;
 
+    my %labels;
+    @labels{@$values} = @$labels;
+
     my $select_features = $self->language->tr('SUBTRACKS_SHOWN');
     $select_features   .= ul({-style=>'list-style: none;margin:0,0,0,0'},
-			      map {$filter->{values}{$_} ? li($_)
-				                         : li({-style=>'color: gray'},$_)
-			      } @values);
+			      map {$filter->{values}{$_} ? li($labels{$_})
+				                         : li({-style=>'color: gray'},$labels{$_})
+			      } @$values);
 				 
 
     $select_features   .= $self->language->tr('SELECT_SUBTRACKS');
@@ -1394,6 +1391,19 @@ sub generate_filters {
     return \%filters;
 }
 
+sub set_subtrack_defaults {
+    my $self = shift;
+    my $label = shift;
+    my $settings = $self->settings;
+    my $source   = $self->source;
+
+    if (my @defaults = $source->subtrack_select_default($label)) {
+	my ($method) = $source->subtrack_select_list($label);
+	$settings->{features}{$label}{filter}{values} ||= {map {$_=>1} @defaults};
+	$settings->{features}{$label}{filter}{method} ||= $method;
+    }
+}
+
 sub subtrack_select_filter {
     my $self     = shift;
     my ($settings,$label) = @_;
@@ -1418,7 +1428,6 @@ sub {
     return;
 }
 END
-
     my $cref = eval $sub;
     warn "failed compiling $sub: ",$@ if $@;
     return $cref;
